==> o3-form-0.3.0.tgz: package/esm/CheckBox.js <==
import { jsx, jsxs } from "react/jsx-runtime";
import { createElement } from "react";
import { LabeledFormField, FormFieldset } from "./fieldComponents/FormField";
const CheckBoxItem = (props) => {
  let { inputId, attributes, optional, error } = props;
  const classNames = ["o3-form-input__checkbox-input", "o3-visually-hidden"];
  if (error) {
    classNames.push("o3-form-input-error");
  }
  return /* @__PURE__ */ jsxs("div", { className: "o3-form-input__checkbox", children: [
    /* @__PURE__ */ jsx(
      "input",
      {
        ...attributes,
        type: "checkbox",
        id: inputId,
        className: classNames.join(" "),
        required: !optional,
        "aria-required": !optional
      }
    ),
    /* @__PURE__ */ jsx("label", { htmlFor: inputId, className: "o3-form-input__checkbox-label", children: props.checkboxLabel })
  ] });
};
const CheckBox = (props) => {
  const newProps = {
    ...props,
    labelId: props.inputId,
    descriptionId: props.inputId
  };
  return /* @__PURE__ */ jsx(LabeledFormField, { ...newProps, children: /* @__PURE__ */ jsx(CheckBoxItem, { ...newProps, children: " " }) });
};
const CheckBoxGroup = (props) => {
  const { children, ...restProps } = props;
  return /* @__PURE__ */ jsx(FormFieldset, { ...restProps, children: children.map((child) => {
    const hasError = props.feedback?.errorElementIds?.includes(
      child.props.inputId
    );
    return /* @__PURE__ */ createElement(
      CheckBoxItem,
      {
        ...child.props,
        error: hasError,
        key: child.props.inputId
      }
    );
  }) });
};
export {
  CheckBox,
  CheckBoxGroup,
  CheckBoxItem
};

==> o3-form-0.3.3.tgz: package/esm/CheckBox.js <==
import { jsx, jsxs } from "react/jsx-runtime";
import { createElement } from "react";
import { TitledFormField, FormFieldset } from "./fieldComponents/FormField";
const CheckBoxItem = (props) => {
  let { inputId, attributes, optional, error } = props;
  const classNames = ["o3-form-input__checkbox-input", "o3-visually-hidden"];
  if (error) {
    classNames.push("o3-form-input-error");
  }
  return /* @__PURE__ */ jsxs("div", { className: "o3-form-input__checkbox", children: [
    /* @__PURE__ */ jsx(
      "input",
      {
        ...attributes,
        type: "checkbox",
        id: inputId,
        className: classNames.join(" "),
        required: !optional,
        "aria-required": !optional
      }
    ),
    /* @__PURE__ */ jsx("label", { htmlFor: inputId, className: "o3-form-input__checkbox-label", children: props.checkboxLabel })
  ] });
};
const CheckBox = (props) => {
  const newProps = {
    ...props,
    labelId: props.inputId,
    descriptionId: props.inputId
  };
  return /* @__PURE__ */ jsx(TitledFormField, { ...newProps, children: /* @__PURE__ */ jsx(CheckBoxItem, { ...newProps, children: " " }) });
};
const CheckBoxGroup = (props) => {
  const { children, ...restProps } = props;
  return /* @__PURE__ */ jsx(FormFieldset, { ...restProps, children: children.map((child) => {
    const hasError = props.feedback?.errorElementIds?.includes(
      child.props.inputId
    );
    return /* @__PURE__ */ createElement(
      CheckBoxItem,
      {
        ...child.props,
        error: hasError,
        key: child.props.inputId
      }
    );
  }) });
};
export {
  CheckBox,
  CheckBoxGroup,
  CheckBoxItem
};
